/// <reference types="node" />
import { promises as fs, Stats, MakeDirectoryOptions } from "fs";
export declare abstract class AnyFile {
    private _path;
    constructor(path: string);
    is<T extends AnyFile>(type: FileType<T>): this is T;
    abstract verify(): Promise<boolean>;
    readonly path: string;
    protected trim(path: string): string;
    readonly name: string;
    readonly parentPath: string;
    stat(): Promise<Stats>;
    exists(): Promise<boolean>;
    parent(): Folder;
    rename(newPath: string): Promise<void>;
    remove(): Promise<void>;
}
export declare type FileType<T extends AnyFile = AnyFile> = {
    new (path: string): T;
};
export declare class Unknown extends AnyFile {
    verify(): Promise<boolean>;
}
export declare class File extends AnyFile {
    verify(): Promise<boolean>;
    open(flags: string | number, mode?: string | number): Promise<fs.FileHandle>;
    readonly suffix: string;
    readonly suffixes: string[];
}
export declare class Folder extends AnyFile {
    verify(): Promise<boolean>;
    children(opts?: {
        castable?: FileType[];
    }): Promise<AnyFile[]>;
    remove(): Promise<void>;
    static make(path: string, opts?: MakeDirectoryOptions): Promise<Folder>;
}
